/****************************************************************************
 * check namespace[pdfTags] and see if it has a **firstLoad** property *
 * i.e.：
    Array.prototype.forEach.call(pdfTags, function(el, i) {
        // if namespace[pdfTags] don't have a **firstLoad** property, return;
        if(!isFirstLoad(el, 'dch.js')) {
            return;
        }
        el.addEventListener('click', function(e) {
            // codes for click event...
        }
    });
****************************************************************************/
var isFirstLoad = function (namesp, jsFile) {
    var isFirst = namesp.firstLoad === undefined;
    namesp.firstLoad = false;

    if (!isFirst) {
        console.log('Warning: Javascirpt file is included twice: ' + jsFile);
    }

    return isFirst;
};

// ready
function ready(fn) {
    if (
        document.attachEvent
            ? document.readyState === 'complete'
            : document.readyState !== 'loading'
    ) {
        fn();
    } else {
        document.addEventListener('DOMContentLoaded', fn);
    }
}

// fix goldendict bug: when two headwords displayed in the same document,
// the second one displayed no style
function moveDictItem() {
    if (!document.querySelectorAll('.gdarticle')) return;
    var gdarticle = document.querySelectorAll('.gdarticle');

    Array.prototype.forEach.call(gdarticle, function (el, i) {
        if (!el.nextElementSibling) return;
        if (!el.nextElementSibling.classList) return;
        if (/mdict/.test(el.nextElementSibling.classList)) {
            var gdarticlebody = el.querySelector('.gdarticlebody'),
                copy = el.nextElementSibling;
            gdarticlebody.appendChild(copy);
            el.nextElementSibling.remove();
            moveDictItem();
        }
    });
}
ready(moveDictItem);

function four(num) {
    var a = '',
        b = 4 - num.toString().length;
    for (var i = 0; i < b; i++) {
        a += '0';
    }
    return a + num;
}

/***************
 * load image *
 **************/
function cyLoadImage(parent, el, imgUrl) {
    var guideLinks = document.createElement('div'),
        imgSuit = parent.querySelector('.img_suit'),
        wordPage = document.createElement('span'),
        currentPage = parent.querySelector('.cy_page').dataset.page,
        posx = parent.querySelector('.cy_page').dataset.posx,
        posy = parent.querySelector('.cy_page').dataset.posy,
        colorBlock = document.createElement('span');

    wordPage.setAttribute('data-page', currentPage);
    wordPage.setAttribute('class', 'word_page cy_guide');
    wordPage.innerHTML = '\u8FD4\u56DE' + currentPage + '\u9801';
    if (posx < 200) {
        imgSuit.classList.remove('middle');
        imgSuit.classList.remove('right');
        imgSuit.classList.add('left');
        colorBlock.style.left = 0;
    } else if (posx > 1000 && posx < 2000) {
        imgSuit.classList.remove('left');
        imgSuit.classList.remove('right');
        imgSuit.classList.add('middle');
        colorBlock.style.left = 341 + 'px';
    } else {
        imgSuit.classList.remove('left');
        imgSuit.classList.remove('middle');
        imgSuit.classList.add('right');
        colorBlock.style.left = 682 + 'px';
    }
    colorBlock.setAttribute('class', 'float');

    // A01.jpg, A02.jpg, 4923.jpg, 4924.jpg
    // A03-A31.png, 0001-4922.png
    // main content pages: 0001-4767
    var url = imgUrl.match(/([^.]+?)(\.png|\.jpg)/),
        pageNum = url[1].match(/A([\d]+)/)
            ? Number(url[1].slice(1))
            : Number(url[1]),
        preNum,
        nextNum,
        preUrl,
        nextUrl;
    var imgElement = document.querySelector('main img');
    var imgUrl = imgElement.src;
    var getUrl = imgUrl.match(/([\s\S]+?\/)[^/.]+\.(?:png|jpg)/);
        urlPath = getUrl[1];
    var imgNum = String(pageNum).padStart(4, '0');

    // create Image
    var Img = new Image();
    Img.setAttribute('src', urlPath + imgNum + '.png');
    Img.setAttribute('class', 'pdf_img');
    Img.addEventListener('load', function () {
        parent.classList.remove('loading');
        parent.classList.add('loaded');
        imgSuit.innerHTML = '';

        var pre = document.createElement('b'),
            next = document.createElement('b'),
            current = document.createElement('span');
        // menuList = document.createElement('a');
        pre.setAttribute('class', 'pre');
        next.setAttribute('class', 'next');
        pre.innerHTML = '\u4E0A\u4E00\u9801';
        next.innerHTML = '\u4E0B\u4E00\u9801';
        current.setAttribute('class', 'current');
        // menuList.setAttribute('href', 'entry://目录');
        // menuList.setAttribute('class', 'menu_list');
        // menuList.innerHTML = '\u76EE\u5F55';

        // if not in the page of the search word, show the link return to it
        if (currentPage != url[1]) {
            imgSuit.appendChild(wordPage);
            imgSuit.classList.remove('left');
            imgSuit.classList.remove('middle');
            imgSuit.classList.remove('right');
            colorBlock.style.display = 'none';
        } else {
            colorBlock.style.display = 'block';
        }
        colorBlock.style.top = (posy / Img.height) * 100 + '%';
        // imgSuit.appendChild(menuList);
        imgSuit.appendChild(pre);
        imgSuit.appendChild(current);
        imgSuit.appendChild(next);
        var imgSlide = document.createElement('div');
        imgSlide.setAttribute('class', 'img_slide');
        imgSlide.appendChild(Img);
        imgSlide.appendChild(colorBlock);
        imgSuit.appendChild(imgSlide);

        var clonePre = pre.cloneNode(true),
            cloneCurrent = current.cloneNode(true),
            cloneNext = next.cloneNode(true);
        // cloneMenuList = menuList.cloneNode(true);
        // imgSuit.appendChild(cloneMenuList);
        imgSuit.appendChild(clonePre);
        imgSuit.appendChild(cloneCurrent);
        imgSuit.appendChild(cloneNext);

        current.innerHTML = cloneCurrent.innerHTML = url[1];

        if (/A([\d]+)/.test(url[1])) {
            switch (pageNum) {
                case 1:
                    preNum = '4924.jpg';
                    nextNum = 'A02.jpg';
                    break;
                case 2:
                    preNum = 'A01.jpg';
                    nextNum = 'A03.png';
                    break;
                case 3:
                    preNum = 'A02.jpg';
                    nextNum = 'A04.png';
                    break;
                case 31:
                    preNum = 'A30.png';
                    nextNum = '0001.png';
                    break;
                default:
                    preNum =
                        'A' +
                        (pageNum - 1 < 10 ? '0' + (pageNum - 1) : pageNum - 1) +
                        '.png';
                    nextNum =
                        'A' +
                        (pageNum + 1 < 10 ? '0' + (pageNum + 1) : pageNum + 1) +
                        '.png';
                    break;
            }
            preUrl = urlPath + preNum;
            nextUrl = urlPath + nextNum;
        } else if (Number(url[1]) > 4923) {
            switch (pageNum) {
                case 4924:
                    preNum = '4923.jpg';
                    nextNum = 'A01.jpg';
                    preUrl = urlPath + preNum;
                    nextUrl = urlPath + nextNum;
                    break;
            }
        } else {
            switch (pageNum) {
                case 1:
                    preNum = 'A31.png';
                    nextNum = '0002.png';
                    break;
                case 4922:
                    preNum = '4921.png';
                    nextNum = '4923.jpg';
                    break;
                case 4923:
                    preNum = '4922.png';
                    nextNum = '4924.jpg';
                    break;
                case 4924:
                    preNum = '4923.jpg';
                    nextNum = 'A01.jpg';
                    break;
                default:
                    preNum =
                        (pageNum - 1 < 1000 ? four(pageNum - 1) : pageNum - 1) +
                        '.png';
                    nextNum =
                        (pageNum + 1 < 1000 ? four(pageNum + 1) : pageNum + 1) +
                        '.png';
                    break;
            }
            preUrl = urlPath + preNum;
            nextUrl = urlPath + nextNum;
        }
        pre.addEventListener(
            'click',
            function () {
                cyLoadImage(this.parentNode.parentNode, el, preNum);
            },
            false
        );
        next.addEventListener(
            'click',
            function () {
                cyLoadImage(this.parentNode.parentNode, el, nextNum);
            },
            false
        );
        clonePre.addEventListener(
            'click',
            function () {
                cyLoadImage(this.parentNode.parentNode, el, preNum);
            },
            false
        );
        cloneNext.addEventListener(
            'click',
            function () {
                cyLoadImage(this.parentNode.parentNode, el, nextNum);
            },
            false
        );

        // guideLinks.setAttribute('class', 'guide_links');
        // guideLinks.innerHTML = '<span data-page="A14" class="cy_guide">\u7B2C\u4E8C\u7248\u4FEE\u8BA2\u8BF4\u660E</span><span data-page="A17" class="cy_guide">\u524D\u8A00</span><span data-page="A19" class="cy_guide">\u51E1\u4F8B</span><br><span data-page="5131" class="cy_guide">\u65B0\u65E7\u5B57\u5F62\u5BF9\u7167\u8868</span><span data-page="5132" class="cy_guide">\u6C49\u8BED\u62FC\u97F3\u65B9\u6848</span><span data-page="5133" class="cy_guide">\u56FD\u9645\u97F3\u6807\u8868</span><span data-page="5134" class="cy_guide">\u7B80\u5316\u5B57\u603B\u8868</span><span data-page="5148" class="cy_guide">\u73B0\u4EE3\u6C49\u8BED\u5E38\u7528\u5B57\u8868</span><span data-page="5154" class="cy_guide">\u73B0\u4EE3\u6C49\u8BED\u901A\u7528\u5B57\u8868</span><span data-page="5170" class="cy_guide">\u666E\u901A\u8BDD\u5F02\u8BFB\u8BCD\u5BA1\u97F3\u8868</span><span data-page="5182" class="cy_guide">\u4E2D\u56FD\u5386\u53F2\u7EAA\u5E74\u8868</span><span data-page="5243" class="cy_guide">\u4E3B\u8981\u5F15\u7528\u4E66\u76EE\u8868</span><br><span data-page="5353" class="cy_guide">\u7B14\u753B\u68C0\u5B57\u8868</span><span data-page="5547" class="cy_guide">\u97F3\u5E8F\u68C0\u5B57\u8868</span><br><span data-page="5726" class="cy_guide">\u540E\u8BB0</span><span data-page="A23" class="cy_guide">\u9644\uFF1A\u521D\u7248\u300A\u6C49\u8BED\u5927\u5B57\u5178\u300B\u90E8\u9996\u8868</span>';
        // if(!parent.querySelector('.guide_links')) {
        //     parent.appendChild(guideLinks);
        // }

        var guide = document.querySelectorAll('.cy_guide');

        Array.prototype.forEach.call(guide, function (element, i) {
            element.addEventListener('click', function (e) {
                imgUrl = this.dataset.page + '.png';
                cyLoadImage(this.parentNode.parentNode, element, imgUrl);
            });
        });
    });
    Img.addEventListener('error', function () {
        parent.classList.remove('loading');
        el.classList.add('error');
    });
}

// open online pdf images
function cyHolePage() {
    var pdfTags = document.querySelectorAll('.cy_page');

    Array.prototype.forEach.call(pdfTags, function (el, i) {
        /* check namespace[el] and see if it has a **firstLoad** property */
        if (!isFirstLoad(el, 'cy_script.js')) {
            return;
        }

        el.addEventListener('click', function (e) {
            var parent = el.parentNode,
                imgUrl = this.dataset.page + '.png';

            // create image suit
            if (!parent.querySelector('.img_suit')) {
                var imgSuit = document.createElement('div');
                imgSuit.setAttribute('class', 'img_suit');
                parent.appendChild(imgSuit);
                parent.classList.add('loading');
                cyLoadImage(parent, el, imgUrl);
            }

            if (/cy_page/.test(el.classList)) {
                parent.classList.toggle('on');
            }
        });
    });
}
ready(cyHolePage);
